@@ -10,13 +10,13 @@ extract_fluorescence_extrema <- function(
   assert_is_a_number(attr(x, "ZeroTimePoint"))
   if (!is.null(timepoint_of_measurement))
       assert_is_a_number(timepoint_of_measurement)
-  assertive.numbers::assert_all_are_in_closed_range(
+  assert_all_are_in_closed_range(
     timepoint_of_measurement,
     lower = min(x$Time.in.sec, na.rm = TRUE),
     upper = max(x$Time.in.sec, na.rm = TRUE))
   is_a_number(n_averaging)
-  assertive.numbers::assert_all_are_positive(n_averaging)
-  assertive.numbers::assert_all_are_whole_numbers(n_averaging)
+  assert_all_are_positive(n_averaging)
+  assert_all_are_whole_numbers(n_averaging)
 
   # Extract baseline fluorescence -------------------------------------------
   min_fluorescence_to_extract <- x %>%
